# check_internet_speed
Check Internet Speed
[![Downloads](https://static.pepy.tech/personalized-badge/check-internet-speed?period=total&units=international_system&left_color=black&right_color=blue&left_text=Downloads)](https://pepy.tech/project/check-internet-speed)[![GitHub license](https://img.shields.io/github/license/sujitmandal/check-internet-speed)](https://github.com/sujitmandal/check-internet-speed/blob/master/LICENSE) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/check-internet-speed) ![PyPI - Wheel](https://img.shields.io/pypi/wheel/check-internet-speed) ![PyPI](https://img.shields.io/pypi/v/check-internet-speed) 




```
Check Internet Speed

checking internet upload and download speed.
```


## Package Installation : 
```
pip install check-internet-speed
```
[Pypi Package Link](https://pypi.org/project/check-internet-speed/)


## How to import the module:
```python
from check_internet_speed.check_internet_speed import check_internet_speed

status = check_internet_speed()

print(status)
```





## License:
MIT Licensed

## Author:
Sujit Mandal

[GitHub](https://github.com/sujitmandal)

[PyPi](https://pypi.org/user/sujitmandal/)

[LinkedIn](https://www.linkedin.com/in/sujit-mandal-91215013a/)
